(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   6619737,     138281]
NotebookOptionsPosition[   6618122,     138232]
NotebookOutlinePosition[   6618481,     138248]
CellTagsIndexPosition[   6618438,     138245]
WindowFrame->Generic*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "group", " ", "of", " ", "cells", " ", "is", " ", "used", " ",
     "to", " ", "compute", " ", "the", " ", "freezeout", " ", "curve", " ", 
    "in", " ", "terms", " ", "of", " ", 
    RowBox[{"mu", "/", "T"}], " ", "and", " ", 
    RowBox[{"T", "/", "Tc"}]}], " ", "*)"}],
  FontSize->16]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.470550874722187*^9, 3.470550918407294*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Parametrization", " ", "from", " ", 
    RowBox[{"arXiv", ":", "0910.2128"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"pa", "=", 
     RowBox[{"{", 
      RowBox[{"0.166", ",", " ", "0.002"}], "}"}]}], ";"}], " ", 
   RowBox[{"(*", " ", "GeV", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pb", "=", 
     RowBox[{"{", 
      RowBox[{"0.139", ",", " ", "0.016"}], "}"}]}], " ", ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"1", "/", "GeV"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pc", "=", 
     RowBox[{"{", 
      RowBox[{"0.053", ",", " ", "0.021"}], "}"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"1", "/", 
     RowBox[{"GeV", "^", "3"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pd", "=", 
     RowBox[{"{", 
      RowBox[{"1.308", ",", "0.028"}], "}"}]}], ";"}], " ", 
   RowBox[{"(*", " ", "GeV", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pe", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"0.273", ",", " ", "0.008"}], "}"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"1", "/", "GeV"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"temp", "[", "x_", "]"}], " ", ":=", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"pa", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"x", "^", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"pb", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"x", "^", "2"}], " ", 
           RowBox[{"pc", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}]}]}], ",", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"pa", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "^", "2"}], "  ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "^", "2"}], " ", 
           RowBox[{"pb", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], " ", ")"}], "^", "2"}], " ", 
        "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "^", "4"}], 
           RowBox[{"pc", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", "2"}]}], "]"}]}], 
     " ", "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mu", "[", "x_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"pd", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", " ", 
        RowBox[{
         RowBox[{"pe", "[", 
          RowBox[{"[", "1", "]"}], "]"}], " ", "x"}]}], ")"}]}], " ", 
     RowBox[{"{", " ", 
      RowBox[{"1", ",", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pd", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "/", 
            RowBox[{"pd", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", "2"}], " ", "+", 
         " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pe", "[", 
             RowBox[{"[", "2", "]"}], "]"}], " ", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                RowBox[{"pe", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], " ", "x"}]}], ")"}]}]}], 
           ")"}], "^", "2"}]}], "]"}]}], "}"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"frz", "[", 
     RowBox[{"x_", ",", "tc_"}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mub", ",", "t", ",", " ", "te"}], "}"}], ",", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Determine", " ", "mub"}], " ", "*)"}], "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"mub", "=", " ", 
        RowBox[{"mu", "[", "x", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Determine", " ", "t"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"t", "=", 
        RowBox[{"temp", "[", 
         RowBox[{"mub", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", " ", 
       RowBox[{"t", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"t", ",", 
          RowBox[{"temp", "[", 
           RowBox[{
            RowBox[{"mub", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "-", 
            RowBox[{"mub", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", " ", 
       RowBox[{"t", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"t", ",", 
          RowBox[{"temp", "[", 
           RowBox[{
            RowBox[{"mub", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "+", 
            RowBox[{"mub", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"te", "=", 
        RowBox[{"Max", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"t", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "-", 
            RowBox[{"t", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{"t", "[", 
             RowBox[{"[", "5", "]"}], "]"}], "-", 
            RowBox[{"t", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
           RowBox[{"t", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"t", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"t", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "te"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Determine", " ", 
         RowBox[{"mub", "/", "T"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"mub", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"mub", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/", 
          RowBox[{"t", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], 
         RowBox[{"{", 
          RowBox[{"1", ",", " ", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"mub", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "/", 
                RowBox[{"mub", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", "2"}], " ", 
             "+", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"t", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "/", 
                RowBox[{"t", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", "2"}]}], 
            "]"}]}], "}"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Determine", " ", 
         RowBox[{"T", "/", "Tc"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"t", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"t", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/", "tc"}], 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"t", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "/", 
            RowBox[{"t", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "x", ",", "\"\<\\t\>\"", ",", "mub", ",", "\"\<\\t\>\"", ",", "t"}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"mub", ",", "t"}], "}"}]}]}], "]"}]}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.47046286777049*^9, 3.470463115347984*^9}, {
  3.470463227970724*^9, 3.470463576538444*^9}, {3.470463628617856*^9, 
  3.470463671714509*^9}, {3.470463861437103*^9, 3.470463982362106*^9}, {
  3.470464037138832*^9, 3.470464269050783*^9}, {3.470464317408126*^9, 
  3.470464356336399*^9}, {3.470464406349049*^9, 3.470464542158812*^9}, {
  3.47046826365746*^9, 3.470468268312655*^9}, {3.470468502009149*^9, 
  3.470468521400806*^9}, {3.4704748644019*^9, 3.47047486931007*^9}, {
  3.470474979309983*^9, 3.470474980743191*^9}, {3.470475377878622*^9, 
  3.470475385958856*^9}, {3.470550573106053*^9, 3.470550599881815*^9}, {
  3.470550776916187*^9, 3.470550808336781*^9}, {3.470550868313434*^9, 
  3.470550870848556*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Low", " ", "Tc", " ", "scenario"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"frz", "[", 
    RowBox[{"5000", ",", "0.175"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"2500", ",", "0.175"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"850", ",", "0.175"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"200", ",", "0.175"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"62.4", ",", "0.175"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"39", ",", "0.175"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"27", ",", "0.175"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"19.6", ",", "0.175"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"18", ",", "0.175"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"11.5", ",", "0.175"}], "]"}], ";", 
   RowBox[{"frz", "[", 
    RowBox[{"7.7", ",", "0.175"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"5", ",", "0.175"}], "]"}], ";"}], " "}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.470464283330852*^9, 3.470464285151963*^9}, {
   3.470464545357002*^9, 3.470464572575014*^9}, {3.470464634810564*^9, 
   3.470464695826592*^9}, {3.470550610022609*^9, 3.470550687630725*^9}, 
   3.470550808336841*^9, {3.472867876028075*^9, 3.472867913337601*^9}, {
   3.472867944840107*^9, 3.472867950423848*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"High", " ", "Tc", " ", "scenario"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"frz", "[", 
    RowBox[{"5000", ",", "0.192"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"2500", ",", "0.192"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"850", ",", "0.192"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"200", ",", "0.192"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"62.4", ",", "0.192"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"39", ",", "0.192"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"27", ",", "0.192"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"19.6", ",", "0.192"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"18", ",", "0.192"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"11.5", ",", "0.192"}], "]"}], ";", 
   RowBox[{"frz", "[", 
    RowBox[{"7.7", ",", "0.192"}], "]"}], ";", " ", 
   RowBox[{"frz", "[", 
    RowBox[{"5", ",", "0.192"}], "]"}], ";"}], " "}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.470550691011672*^9, 3.470550737556904*^9}, 
   3.470550808336877*^9, {3.472867921873376*^9, 3.47286796321095*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "group", " ", "of", " ", "cells", " ", "is", " ", "used", " ",
     "to", " ", "compute", " ", "the", " ", "Pade", " ", "coefficients", " ", 
    "for", " ", "various", " ", "ratios"}], " ", "*)"}],
  FontSize->16]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.470550954228823*^9, 3.470550977978667*^9}, 
   3.470553738012924*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "series", " ", "expansions"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"chi2", " ", "=", " ", 
    RowBox[{
     RowBox[{"c2", " ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "+", "  ", 
        RowBox[{
         RowBox[{"z", "^", "2"}], "/", 
         RowBox[{"r42", "^", "2"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"z", "^", "4"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r64", "^", "2"}], " ", 
           RowBox[{"r42", "^", "2"}]}], ")"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"z", "^", "6"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r86", "^", "2"}], " ", 
           RowBox[{"r64", "^", "2"}], " ", 
           RowBox[{"r42", "^", "2"}]}], ")"}]}]}], " ", ")"}]}], "+", " ", 
     RowBox[{
      RowBox[{"O", "[", "z", "]"}], "^", "8"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"chi3", " ", "=", " ", 
    RowBox[{"D", "[", 
     RowBox[{"chi2", ",", "z"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"chi4", " ", "=", " ", 
    RowBox[{"D", "[", 
     RowBox[{"chi2", ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"m1", " ", "=", " ", 
    RowBox[{"chi3", "/", 
     RowBox[{"(", 
      RowBox[{"z", " ", "chi2"}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"m3", " ", "=", " ", 
    RowBox[{"z", " ", 
     RowBox[{"chi4", "/", "chi3"}]}]}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.47055099230946*^9, 3.47055115394652*^9}, {
   3.470551488778592*^9, 3.470551560038132*^9}, 3.47055373801297*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "P11", " ", "pade", " ", "coefficients"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p11", "[", 
     RowBox[{"ser_", ",", "z_"}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "f0", ",", " ", "f1", ",", " ", "f2", ",", " ", "a0", ",", " ", "a1", 
        ",", " ", "b1"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f0", " ", "=", " ", 
        RowBox[{"ser", " ", "/.", " ", 
         RowBox[{"z", " ", "\[Rule]", " ", "0"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"f1", " ", "=", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"ser", ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "2"}], "}"}]}], "]"}], " ", "/.", " ", 
         RowBox[{"z", " ", "\[Rule]", " ", "0"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"f2", " ", "=", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"ser", ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "4"}], "}"}]}], "]"}], " ", "/.", " ", 
         RowBox[{"z", " ", "\[Rule]", " ", "0"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"b1", " ", "=", " ", 
        RowBox[{
         RowBox[{"-", " ", "f2"}], "/", "f1"}]}], ";", " ", 
       RowBox[{"a0", "=", " ", "f0"}], ";", " ", 
       RowBox[{"a1", " ", "=", " ", 
        RowBox[{"f1", " ", "+", " ", 
         RowBox[{"b1", " ", "f0"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Apart", "[", 
        RowBox[{"Together", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"a0", ",", "a1"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "b1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"f0", ",", "f1", ",", "f2"}], "}"}]}], "}"}], "]"}], 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"p11", "[", 
    RowBox[{"m1", ",", "z"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"p11", "[", 
    RowBox[{"m3", ",", "z"}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.47055116655175*^9, 3.470551315600947*^9}, {
   3.47055134871757*^9, 3.470551465574947*^9}, {3.470551598299497*^9, 
   3.47055166933627*^9}, {3.470551797881502*^9, 3.470551806273039*^9}, 
   3.470553738013002*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "P01", " ", "pade", " ", "coefficients"}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p01", "[", 
     RowBox[{"ser_", ",", "z_"}], "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "f0", ",", " ", "f1", ",", " ", "f2", ",", " ", "a0", ",", " ", "b1"}],
        "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f0", " ", "=", " ", 
        RowBox[{"ser", " ", "/.", " ", 
         RowBox[{"z", " ", "\[Rule]", " ", "0"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"f1", " ", "=", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"ser", ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "2"}], "}"}]}], "]"}], " ", "/.", " ", 
         RowBox[{"z", " ", "\[Rule]", " ", "0"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"f2", " ", "=", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{"ser", ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "4"}], "}"}]}], "]"}], " ", "/.", " ", 
         RowBox[{"z", " ", "\[Rule]", " ", "0"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"b1", " ", "=", " ", 
        RowBox[{
         RowBox[{"-", " ", "f2"}], "/", "f1"}]}], ";", " ", 
       RowBox[{"a0", "=", " ", "f0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Apart", "[", 
        RowBox[{"Together", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", "a0", "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "b1"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"f0", ",", "f1", ",", "f2"}], "}"}]}], "}"}], "]"}], 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"p01", "[", 
    RowBox[{"m1", ",", "z"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"p01", "[", 
    RowBox[{"m3", ",", "z"}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.470551697886405*^9, 3.470551778998016*^9}, {
  3.470553717517983*^9, 3.470553738013035*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Random", " ", "nonnormal", " ", "matrices"}], " ", "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"nd", "=", "4"}], ";", " ", 
    RowBox[{"mx", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"id", " ", "=", " ", 
     RowBox[{"Table", "[", " ", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "nd"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "nd"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"id", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "i"}], "]"}], "]"}], "=", "1"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "nd"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Random", "[", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "nd"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "nd"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"res", "=", 
     RowBox[{
      RowBox[{"Inverse", "[", 
       RowBox[{
        RowBox[{"z", " ", "id"}], "-", "m"}], "]"}], " ", "/.", " ", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"I", " ", "y"}]}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"norm", "=", 
     RowBox[{"0.5", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"res", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}], "]"}], "^", "2"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "nd"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "nd"}], "}"}]}], "]"}], "]"}]}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"norm", "\[Equal]", "0"}], ",", "  ", 
       RowBox[{"norm", "\[Equal]", "1"}], ",", " ", 
       RowBox[{"norm", "==", "2"}], ",", " ", 
       RowBox[{"norm", "\[Equal]", "3"}], ",", " ", 
       RowBox[{"norm", "\[Equal]", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "mx"}], ",", "mx"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "mx"}], ",", "mx"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.472966550992177*^9, 3.472966617836522*^9}, {
   3.472966672819222*^9, 3.472966920511463*^9}, {3.472966973880953*^9, 
   3.472966978875228*^9}, {3.472967024190529*^9, 3.47296708175933*^9}, {
   3.472967166773517*^9, 3.47296719867138*^9}, {3.472967263454554*^9, 
   3.472967346698644*^9}, {3.472978986904797*^9, 3.472979119799225*^9}, {
   3.472979159898052*^9, 3.472979212402064*^9}, {3.472979243540898*^9, 
   3.472979256938244*^9}, {3.472979301372181*^9, 3.472979488442199*^9}, {
   3.472979612974706*^9, 3.472979622014105*^9}, {3.472979652950188*^9, 
   3.472979675562757*^9}, {3.473215934331312*^9, 3.473216009819448*^9}, {
   3.47321606077651*^9, 3.473216157645788*^9}, {3.473216269245742*^9, 
   3.473216325615686*^9}, {3.473216367730629*^9, 3.473216494416052*^9}, {
   3.473216532802565*^9, 3.473216606681977*^9}, 3.473216642726036*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxlWXlcjdv3LpKZjEXoUghFIRWudRJJZIwimacGyZCb4RIVkakkQ6RSJM0l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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 
        117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 
        145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 
        159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 
        173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 
        187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 
        201, 202, 203, 204, 205, 206, 207, 208}]},
      RowBox[{
        RowBox[{"0.5`", " ", 
          RowBox[{"Log", "[", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.11267388552881058`"}], "+", 
                    RowBox[{"0.5003870825568064`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.05082618205971315`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.012921853073284077`", "\[InvisibleSpace]"}], 
                    "+", 
                    RowBox[{"0.02086170270453467`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.10700459144550106`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.0015599478427194904`"}], "+", 
                    RowBox[{"0.13466023158012302`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.11019051198449575`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.0413057501543396`"}], "-", 
                    RowBox[{"0.025851356874027814`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.18954460160439465`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.09517013571405564`"}], "+", 
                    RowBox[{"0.5839784895704447`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.2531882337766178`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.07547472270379066`"}], "+", 
                    RowBox[{"0.11211861949912588`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.398906379282459`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.01204429654399629`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.14653614899474318`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.5715740740341917`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.049352927318259604`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.39442583192454117`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.5850938792042112`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.08426584088196659`"}], "+", 
                    RowBox[{"0.04490299062840286`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.6664046948201507`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.16719423803046507`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"1.0200709193979938`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.8765190900491149`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.02794024681424685`"}], "-", 
                    RowBox[{"0.02091960803055959`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.9319200871029738`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.1314989838053281`"}], "+", 
                    RowBox[{"0.24033316731007442`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.9685147555944746`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.017886603859448083`", "\[InvisibleSpace]"}], 
                    "+", 
                    RowBox[{"0.22341119681471244`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.6522950672070083`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.00979176122957269`"}], "+", 
                    RowBox[{"0.24154823333655276`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.3135587198537302`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.1529372039426595`", "\[InvisibleSpace]"}], "-", 
                    RowBox[{"0.5346437855408608`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.1934759646028597`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.17387660376639102`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.3418253445606726`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.0354919460046847`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"]}], "]"}]}], "\[Equal]", "0"}]],
     Annotation[#, 
      0.5 Log[Abs[(-0.11267388552881058` + 
             0.5003870825568064 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.05082618205971315 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.012921853073284077` + 
             0.02086170270453467 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.10700459144550106` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.0015599478427194904` + 
             0.13466023158012302` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.11019051198449575` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.0413057501543396 - 
             0.025851356874027814` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.18954460160439465` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.09517013571405564 + 
             0.5839784895704447 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.2531882337766178 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.07547472270379066 + 
             0.11211861949912588` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.398906379282459 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.01204429654399629 - 
             0.14653614899474318` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.5715740740341917 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.049352927318259604` - 
             0.39442583192454117` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.5850938792042112 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.08426584088196659 + 
             0.04490299062840286 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.6664046948201507 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.16719423803046507` - 
             1.0200709193979938` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.8765190900491149 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.02794024681424685 - 
             0.02091960803055959 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.9319200871029738 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.1314989838053281 + 
             0.24033316731007442` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.9685147555944746 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.017886603859448083` + 
             0.22341119681471244` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) - 
             1.6522950672070083` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.00979176122957269 + 
             0.24154823333655276` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) - 
             1.3135587198537302` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.1529372039426595 - 
             0.5346437855408608 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
             1.1934759646028597` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.17387660376639102` - 
             0.3418253445606726 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
             1.0354919460046847` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2] == 0, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwl0lV0EAQYBeBNUkIBpUEaRLqRlpSGAdIgqeQIaWlBOqS7UVLpUEq6YwO2
MWAwujskP44P3/1f77nnz9AyOKhzYEBAQEpx0j1FCKGc5gxnCSOcCM4RyXku
cJEoLnGZaK5wlWtc5wY3ucVt7nCXe9znAQ95xGOe8JRnPOcFL/mPV7zmDW95
R4D+gXxEDGISi9jEIS4fE4/4JCAhn/ApiUhMEj7jc5KSjOSkCPx/o1SkJg1p
+YJ0pCcDGclEZrKQlWx8SXa+Igc5yUVu8pCXfOSnAAUpRGGKUJSvKUZxSlCS
UpSmDN9QlnKUpwIVqcS3VKYKValGdWpQk1rUJog61KUe31GfBjSkEY1pQlOa
0ZzvaUFLWtGaNrTlB36kHe3pQEc68eH5gulCV7rRnZ/oQU960Zs+9KUfP9Of
AQxkEIMZwlB+YRjD+ZURjGQUoxnDWMYxnglM5DcmMZkpTGUa05nBTGYxmznM
ZR7zWcBCFrGYJSzld/5gGctZwUpWsZo/+Ys1rGUd69nARjaxmS1s5W/+YRvb
2cFOdvEvu9nDXvaxnwMc5BCHOcJRjnGcE5zkFCGEcpoznCWMcCI4RyTnucBF
orjEZaK5wlWucZ0b3OQ9Qe+XzQ==
        "]]},
      RowBox[{
        RowBox[{"0.5`", " ", 
          RowBox[{"Log", "[", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.11267388552881058`"}], "+", 
                    RowBox[{"0.5003870825568064`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.05082618205971315`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.012921853073284077`", "\[InvisibleSpace]"}], 
                    "+", 
                    RowBox[{"0.02086170270453467`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.10700459144550106`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.0015599478427194904`"}], "+", 
                    RowBox[{"0.13466023158012302`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.11019051198449575`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.0413057501543396`"}], "-", 
                    RowBox[{"0.025851356874027814`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.18954460160439465`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.09517013571405564`"}], "+", 
                    RowBox[{"0.5839784895704447`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.2531882337766178`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.07547472270379066`"}], "+", 
                    RowBox[{"0.11211861949912588`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.398906379282459`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.01204429654399629`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.14653614899474318`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.5715740740341917`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.049352927318259604`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.39442583192454117`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.5850938792042112`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.08426584088196659`"}], "+", 
                    RowBox[{"0.04490299062840286`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.6664046948201507`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.16719423803046507`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"1.0200709193979938`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.8765190900491149`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.02794024681424685`"}], "-", 
                    RowBox[{"0.02091960803055959`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.9319200871029738`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.1314989838053281`"}], "+", 
                    RowBox[{"0.24033316731007442`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.9685147555944746`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.017886603859448083`", "\[InvisibleSpace]"}], 
                    "+", 
                    RowBox[{"0.22341119681471244`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.6522950672070083`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.00979176122957269`"}], "+", 
                    RowBox[{"0.24154823333655276`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.3135587198537302`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.1529372039426595`", "\[InvisibleSpace]"}], "-", 
                    RowBox[{"0.5346437855408608`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.1934759646028597`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.17387660376639102`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.3418253445606726`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.0354919460046847`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"]}], "]"}]}], "\[Equal]", "1"}]],
     Annotation[#, 
      0.5 Log[Abs[(-0.11267388552881058` + 
             0.5003870825568064 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.05082618205971315 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.012921853073284077` + 
             0.02086170270453467 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.10700459144550106` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.0015599478427194904` + 
             0.13466023158012302` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.11019051198449575` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.0413057501543396 - 
             0.025851356874027814` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.18954460160439465` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.09517013571405564 + 
             0.5839784895704447 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.2531882337766178 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.07547472270379066 + 
             0.11211861949912588` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.398906379282459 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.01204429654399629 - 
             0.14653614899474318` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.5715740740341917 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.049352927318259604` - 
             0.39442583192454117` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.5850938792042112 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.08426584088196659 + 
             0.04490299062840286 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.6664046948201507 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.16719423803046507` - 
             1.0200709193979938` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.8765190900491149 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.02794024681424685 - 
             0.02091960803055959 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.9319200871029738 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.1314989838053281 + 
             0.24033316731007442` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.9685147555944746 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.017886603859448083` + 
             0.22341119681471244` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) - 
             1.6522950672070083` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.00979176122957269 + 
             0.24154823333655276` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) - 
             1.3135587198537302` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.1529372039426595 - 
             0.5346437855408608 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
             1.1934759646028597` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.17387660376639102` - 
             0.3418253445606726 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
             1.0354919460046847` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2] == 1, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], 
       LineBox[{490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 
        502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 
        516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 
        530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 
        544, 545, 546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 556}], 
       LineBox[{557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568, 
        569, 570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 
        583, 584, 585, 586, 587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 
        597, 598, 599, 600, 601, 602, 603, 604, 605, 606, 607, 608, 609, 610, 
        611, 612, 613, 614, 615, 616, 617, 618, 619, 620}], 
       LineBox[CompressedData["
1:eJwNw2k2AmAAAMAvN+lIHMH/iiQRWQpF2ZLsSZHsISTdrZn3JjqdmIpHQgiT
xiZCiJtwxlmTzply3rQLZlx0yazLrphz1TXX3TBvwU233LZoyR13LVtxz30P
PPTIqsfWPLHuqWeee+GlV17b8Mamt7Zse+e9HR/s+uiTz7746pvv9vzw0y/7
fvvjrwP/HPrvyDGKhTHM
        "]]},
      RowBox[{
        RowBox[{"0.5`", " ", 
          RowBox[{"Log", "[", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.11267388552881058`"}], "+", 
                    RowBox[{"0.5003870825568064`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.05082618205971315`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.012921853073284077`", "\[InvisibleSpace]"}], 
                    "+", 
                    RowBox[{"0.02086170270453467`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.10700459144550106`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.0015599478427194904`"}], "+", 
                    RowBox[{"0.13466023158012302`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.11019051198449575`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.0413057501543396`"}], "-", 
                    RowBox[{"0.025851356874027814`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.18954460160439465`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.09517013571405564`"}], "+", 
                    RowBox[{"0.5839784895704447`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.2531882337766178`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.07547472270379066`"}], "+", 
                    RowBox[{"0.11211861949912588`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.398906379282459`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.01204429654399629`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.14653614899474318`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.5715740740341917`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.049352927318259604`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.39442583192454117`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.5850938792042112`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.08426584088196659`"}], "+", 
                    RowBox[{"0.04490299062840286`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.6664046948201507`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.16719423803046507`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"1.0200709193979938`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.8765190900491149`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.02794024681424685`"}], "-", 
                    RowBox[{"0.02091960803055959`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.9319200871029738`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.1314989838053281`"}], "+", 
                    RowBox[{"0.24033316731007442`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.9685147555944746`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.017886603859448083`", "\[InvisibleSpace]"}], 
                    "+", 
                    RowBox[{"0.22341119681471244`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.6522950672070083`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.00979176122957269`"}], "+", 
                    RowBox[{"0.24154823333655276`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.3135587198537302`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.1529372039426595`", "\[InvisibleSpace]"}], "-", 
                    RowBox[{"0.5346437855408608`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.1934759646028597`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.17387660376639102`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.3418253445606726`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.0354919460046847`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"]}], "]"}]}], "\[Equal]", "2"}]],
     Annotation[#, 
      0.5 Log[Abs[(-0.11267388552881058` + 
             0.5003870825568064 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.05082618205971315 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.012921853073284077` + 
             0.02086170270453467 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.10700459144550106` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.0015599478427194904` + 
             0.13466023158012302` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.11019051198449575` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.0413057501543396 - 
             0.025851356874027814` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.18954460160439465` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.09517013571405564 + 
             0.5839784895704447 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.2531882337766178 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.07547472270379066 + 
             0.11211861949912588` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.398906379282459 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.01204429654399629 - 
             0.14653614899474318` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.5715740740341917 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.049352927318259604` - 
             0.39442583192454117` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.5850938792042112 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.08426584088196659 + 
             0.04490299062840286 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.6664046948201507 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.16719423803046507` - 
             1.0200709193979938` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.8765190900491149 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.02794024681424685 - 
             0.02091960803055959 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.9319200871029738 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.1314989838053281 + 
             0.24033316731007442` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.9685147555944746 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.017886603859448083` + 
             0.22341119681471244` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) - 
             1.6522950672070083` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.00979176122957269 + 
             0.24154823333655276` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) - 
             1.3135587198537302` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.1529372039426595 - 
             0.5346437855408608 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
             1.1934759646028597` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.17387660376639102` - 
             0.3418253445606726 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
             1.0354919460046847` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2] == 2, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], 
       LineBox[{702, 703, 704, 705, 706, 707, 708, 709, 710, 711, 712, 713, 
        714, 715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
        728, 729, 730, 731}], 
       LineBox[{732, 733, 734, 735, 736, 737, 738, 739, 740, 741, 742, 743, 
        744, 745, 746, 747, 748, 749, 750, 751, 752, 753, 754, 755, 756, 757, 
        758, 759, 760, 761, 762, 763, 764}], 
       LineBox[{765, 766, 767, 768, 769, 770, 771, 772, 773, 774, 775, 776, 
        777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 787, 788, 789, 790, 
        791, 792, 793, 794, 795}]},
      RowBox[{
        RowBox[{"0.5`", " ", 
          RowBox[{"Log", "[", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.11267388552881058`"}], "+", 
                    RowBox[{"0.5003870825568064`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.05082618205971315`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.012921853073284077`", "\[InvisibleSpace]"}], 
                    "+", 
                    RowBox[{"0.02086170270453467`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.10700459144550106`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.0015599478427194904`"}], "+", 
                    RowBox[{"0.13466023158012302`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.11019051198449575`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.0413057501543396`"}], "-", 
                    RowBox[{"0.025851356874027814`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.18954460160439465`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.09517013571405564`"}], "+", 
                    RowBox[{"0.5839784895704447`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.2531882337766178`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.07547472270379066`"}], "+", 
                    RowBox[{"0.11211861949912588`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.398906379282459`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.01204429654399629`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.14653614899474318`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.5715740740341917`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.049352927318259604`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.39442583192454117`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.5850938792042112`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.08426584088196659`"}], "+", 
                    RowBox[{"0.04490299062840286`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.6664046948201507`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.16719423803046507`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"1.0200709193979938`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.8765190900491149`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.02794024681424685`"}], "-", 
                    RowBox[{"0.02091960803055959`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.9319200871029738`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.1314989838053281`"}], "+", 
                    RowBox[{"0.24033316731007442`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "+", 
                    RowBox[{"0.9685147555944746`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.017886603859448083`", "\[InvisibleSpace]"}], 
                    "+", 
                    RowBox[{"0.22341119681471244`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.6522950672070083`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "0.00979176122957269`"}], "+", 
                    RowBox[{"0.24154823333655276`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.3135587198537302`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.1529372039426595`", "\[InvisibleSpace]"}], "-", 
                    RowBox[{"0.5346437855408608`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.1934759646028597`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"0.17387660376639102`", "\[InvisibleSpace]"}], 
                    "-", 
                    RowBox[{"0.3418253445606726`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"1.0354919460046847`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], 
                  RowBox[{
                    RowBox[{"-", "0.04411297738679171`"}], "+", 
                    RowBox[{"0.3349086503389259`", " ", 
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], "-", 
                    RowBox[{"0.20575484997513416`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"]}], "-", 
                    RowBox[{"1.7316072325560943`", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "3"]}], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"x", "+", 
                    RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "4"]}]], 
                 "]"}], "2"]}], "]"}]}], "\[Equal]", "3"}]],
     Annotation[#, 
      0.5 Log[Abs[(-0.11267388552881058` + 
             0.5003870825568064 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.05082618205971315 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.012921853073284077` + 
             0.02086170270453467 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.10700459144550106` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.0015599478427194904` + 
             0.13466023158012302` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.11019051198449575` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.0413057501543396 - 
             0.025851356874027814` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.18954460160439465` ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.09517013571405564 + 
             0.5839784895704447 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.2531882337766178 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.07547472270379066 + 
             0.11211861949912588` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.398906379282459 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.01204429654399629 - 
             0.14653614899474318` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.5715740740341917 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.049352927318259604` - 
             0.39442583192454117` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.5850938792042112 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.08426584088196659 + 
             0.04490299062840286 ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.6664046948201507 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.16719423803046507` - 
             1.0200709193979938` ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.8765190900491149 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.02794024681424685 - 
             0.02091960803055959 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) + 
             0.9319200871029738 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.1314989838053281 + 
             0.24033316731007442` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) + 
             0.9685147555944746 ($CellContext`x + 
                Complex[0, 1] $CellContext`y)^2)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.017886603859448083` + 
             0.22341119681471244` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) - 
             1.6522950672070083` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(-0.00979176122957269 + 
             0.24154823333655276` ($CellContext`x + 
               Complex[0, 1] $CellContext`y) - 
             1.3135587198537302` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.1529372039426595 - 
             0.5346437855408608 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
             1.1934759646028597` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2 + 
         Abs[(0.17387660376639102` - 
             0.3418253445606726 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
             1.0354919460046847` ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^2 + ($CellContext`x + 
               Complex[0, 1] $CellContext`y)^3)/(-0.04411297738679171 + 
            0.3349086503389259 ($CellContext`x + 
              Complex[0, 1] $CellContext`y) - 
            0.20575484997513416` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^2 - 
            1.7316072325560943` ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^3 + ($CellContext`x + 
              Complex[0, 1] $CellContext`y)^4)]^2] == 3, "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  PlotRange->{{-3, 3}, {-3, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.473216012159711*^9, {3.473216066329759*^9, 3.473216158677782*^9}, 
   3.473216278872717*^9, 3.473216326290667*^9, {3.473216389553252*^9, 
   3.473216496254241*^9}, 3.473216607233418*^9, {3.473216644989793*^9, 
   3.473216653875607*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{
    StyleBox[
     RowBox[{"(", "*"}]], " ", 
    RowBox[{"Radioactive", " ", "decay"}], " ", "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"nd", "=", "12"}], ";", " ", 
    RowBox[{"mx", "=", "64"}], ";", " ", 
    RowBox[{"my", "=", "15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"m", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "nd"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "nd"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"m", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "i"}], "]"}], "]"}], "=", 
        RowBox[{"-", 
         RowBox[{"Log", "[", 
          RowBox[{"Random", "[", "]"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"nd", "/", "3"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"m", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "i"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{"Random", "[", "]"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{"nd", "/", "3"}], "+", "1"}], ",", 
         RowBox[{"2", 
          RowBox[{"nd", "/", "3"}]}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"m", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "i"}], "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"-", "16"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{"Random", "[", "]"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{"2", 
           RowBox[{"nd", "/", "3"}]}], "+", "1"}], ",", "nd"}], "}"}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"m", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"i", "+", "1"}], ",", "i"}], "]"}], "]"}], " ", "=", " ", 
        RowBox[{"-", " ", 
         RowBox[{"m", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "i"}], "]"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"nd", "-", "1"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"m", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "i"}], "]"}], "]"}], " ", "=", " ", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"I", " ", "y"}], " ", "+", " ", 
         RowBox[{"m", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "i"}], "]"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "nd"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"res", "=", 
      RowBox[{"Inverse", "[", "m", "]"}]}], ";"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"norm", "=", 
     RowBox[{"0.5", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"res", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}], "]"}], "^", "2"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "nd"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "nd"}], "}"}]}], "]"}], "]"}]}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"norm", "\[Equal]", "0"}], ",", "  ", 
       RowBox[{"norm", "\[Equal]", "1"}], ",", " ", 
       RowBox[{"norm", "==", "2"}], ",", " ", 
       RowBox[{"norm", "\[Equal]", "3"}], ",", " ", 
       RowBox[{"norm", "\[Equal]", "4"}], ",", " ", 
       RowBox[{"norm", "\[Equal]", "5"}], ",", " ", 
       RowBox[{"norm", "\[Equal]", "6"}], ",", " ", 
       RowBox[{"norm", "\[Equal]", "7"}], ",", " ", 
       RowBox[{"norm", "\[Equal]", "8"}], ",", " ", 
       RowBox[{"x", "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "mx"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "my"}], ",", "my"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Red", ",", "Blue"}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.47321667230518*^9, 3.473216926857931*^9}, {
  3.473216957741157*^9, 3.473217091638128*^9}, {3.473217268920917*^9, 
  3.473217384629195*^9}, {3.473217416135277*^9, 3.473217430752655*^9}, {
  3.473217550567996*^9, 3.473217562990288*^9}, {3.473217601695202*^9, 
  3.47321762455574*^9}, {3.473217660043266*^9, 3.473217857873553*^9}, {
  3.473218204591302*^9, 3.473218208586694*^9}, {3.473218382964471*^9, 
  3.473218405283545*^9}, {3.473218707773603*^9, 3.47321882142826*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1vHdcz9/7P94eKm1RaO+hRGmeh/YuiczMEBXZm4wSQkY0JBmRrCgjnKuU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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {GrayLevel[0], LineBox[CompressedData["
1:eJwl1FV0EAQYBeA168HGNpZssA1Yj3UXiqiIThEJFaaoGJuBrSChhImABQjY
gYpKKRahYGBjgR0gdjf67fjw3f/9nnP/7M7ujq7AgICAA0TPDSKYEEIJoxfh
RBBJFNHEEEscvelDPAn0JZEkkulHCqmkkU4GmfQni2wGMJAccsljEIMZQj4F
FFJEMSWUUsZQyqmgkiqqqaGWOuppoJEmmmmhlTbaGdbTCQcynIMYwcEcwqGM
5DBGcThH0MGRHMVojmYMxzCWcYxnAsdyHMczkUl0cgInMpmTOJlTmMKpnMbp
nEEX3ZzJWZzNOUzlXM7jfC7gQi7iYi7hUqYxncuYwUxmMZvLuYI5zGUe87mS
q7iaa7iW61jA9SxkEYu5gRu5iZu5hSUsZRm3spwVrOQ2bucO7uQu7uYe7uU+
7mcVD/AgD7Gah3mER1nDWtaxng08xuNs5Ame5Cme5hk2sZktbOVZnmMb23me
F3iRl9jBy7zCq7zG67zBm+zkLd7mHd7lPXaxm/f5gA/5iI/5hE/5jM/5gj3s
5Uv28RVf8w3f8h3f8wM/8hM/8wu/8hu/8wd/8hd/8w/7+Zee8QcSRDAhhBJG
L8KJIJIoookhljh604d4EuhLIkkk048UUkkjnQwy6U8W2QxgIDnkkscgBjOE
fAoopIhiSiiljKGUU0ElVVRTQy111NNAI00000IrbbQzLPD/n/gf8VeLLw==

        "]]},
      RowBox[{
        RowBox[{"0.5`", " ", 
          RowBox[{"Log", "[", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.021157091589337353`"}], "-", 
                   FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.03315723695712985`"}], "+", 
                   FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.017358563477362803`"}], "-", 
                   FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.12002996286708252`"}], "+", 
                   FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.3031777862580342`"}], "-", 
                   FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.21567884822807393`"}], "+", 
                   FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.5220334191228186`"}], "-", 
                   FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.8509010091039361`"}], "+", 
                   FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "3.9372798220531267`"}], "-", 
                   FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "9.73519865353867`"}], "+", 
                   FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "2.870049975526493`"}], "-", 
                   FractionBox[
                    RowBox[{"614524.0300765625`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              FractionBox["1.`", 
               SuperscriptBox[
                RowBox[{"Abs", "[", 
                  RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], "]"}], "2"]], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9.73519865353867`"}], "+", 
                    FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}]}], "]"}]}], "\[Equal]", 
        "0"}]],
     Annotation[#, 
      0.5 Log[Abs[-0.021157091589337353` - 
            1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y)/(
            13.694730952998 + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.03315723695712985 + 
            47.265475775695705` (-0.2897406770639119 - 
              0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.017358563477362803` - 
            1425.4950084292877` (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            47.265475775695705` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.12002996286708252` + 
            82120.56316113181 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.3031777862580342 - 
            684167.1962530689 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.21567884822807393` + 
            2.256653446472411*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.5220334191228186 - 
            1.0463026230954587`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.8509010091039361 + 
            2.0042828385461956`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-3.9372798220531267` - 
            2.3554829728746694`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[-9.73519865353867 + 
            5.9825135101685105`*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[-2.870049975526493 - 
            614524.0300765625 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              0.10272004050338589` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              0.2539824562122541 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
             2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.5671925801862232` - 
              0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.525850871034293 - 
              0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[
               0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[
               0., -0.3031777862580342] $CellContext`y) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[
               0., -0.3031777862580342] $CellContext`y) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y]^(-2) + 
         2234.0252003028777` 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2234.0252003028777` 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[
                0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1. 
          Abs[(-9.73519865353867 + 
              5.9825135101685105`*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 0.2539824562122541 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.1752248373204734` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 57.608453677868795` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
                3.9372798220531267` $CellContext`x + 
                Complex[
                  0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
                Complex[
                  0., -9.73519865353867] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-3.9372798220531267` - 
              2.3554829728746694`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.1752248373204734` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                57.608453677868795` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
               3.9372798220531267` $CellContext`x + 
               Complex[
                 0., -3.9372798220531267`] $CellContext`y)) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-3.9372798220531267` - 
             2.3554829728746694`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.8509010091039361 + 
             2.0042828385461956`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. 
          Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[
                0., -3.9372798220531267`] $CellContext`y) (-2.472569665739981 - 
              9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[
                0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[
               0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[
                0., -2.870049975526493] $CellContext`y) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2] == 0, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwVzlN7kAEAQOFvW7Vcy65l/Y7MpeVa5rJt26tWy6tl27btWrb9dvE+z7k8
kTGxUZ1DgiBIppwoTwUqUonKVKEq1ahODWoSRS1qU4e61COa+jSgIY1oTBOa
0ozmxNCClrSiNW1oSzva04GOdOL/aCxd6Eo3utODnvSiN33oSz/6M4CBDGIw
QxjKMIYzgpGMYjRjGMs4xjOBiUxiMlOYyjSmM4OZzGI2c5jLPOKYzwIWEs8i
FpPAEpayjOWsYCWrSGQ1a0hiLetYzwY2sonNbGEr29jODnayi93sYS/72M8B
DnKIwxzhKMc4zglOcorTnOEs5zjPBS5yictc4SrXuM4NbnKL29zhLve4zwMe
8ojHPOEpyTzjOS94ySte84a3vOM9H/jIJz7zha984zs/+MkvfvOHvwShQRBC
KGGkICWpCCc1aUhLOtKTgYxkIjMRZCEr2chODnKSi9zkIS/5yE8BClKISApT
hKIUozglKEkpSlOGsvwD8D99ng==
        "]], LineBox[CompressedData["
1:eJwNw4dajQEAANA/b9IDiBJCRYqGfcuqSGka95ZRRlsqtAnlokRCSZJVKZR6
LOd834ktiYTCMUEQRN24IQji3ORm401wi4ludZvbTXKHO91lsimmuts9prnX
dDPc534zzTLbHA940EMe9ohHPWbIXPM87glPesrT5ltgoWc8a5HnLLbE85Za
ZrkVVlrlBS96ycuGjVhtjVe86jWvW2udN7zpLW9bb4ONNtlsi63esc27ttth
p/e87wO77LbHXvvsd8CHPnLQxz7xqUMO+8yoz33hS0cc9ZVjvvaN4751wne+
94OTTvnRaT8542dn/eKcX/3md3/403kXXPSXSy772z/+dcVV/7nmuv8BekpO
Lg==
        "]]},
      RowBox[{
        RowBox[{"0.5`", " ", 
          RowBox[{"Log", "[", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.021157091589337353`"}], "-", 
                   FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.03315723695712985`"}], "+", 
                   FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.017358563477362803`"}], "-", 
                   FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.12002996286708252`"}], "+", 
                   FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.3031777862580342`"}], "-", 
                   FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.21567884822807393`"}], "+", 
                   FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.5220334191228186`"}], "-", 
                   FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.8509010091039361`"}], "+", 
                   FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "3.9372798220531267`"}], "-", 
                   FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "9.73519865353867`"}], "+", 
                   FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "2.870049975526493`"}], "-", 
                   FractionBox[
                    RowBox[{"614524.0300765625`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              FractionBox["1.`", 
               SuperscriptBox[
                RowBox[{"Abs", "[", 
                  RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], "]"}], "2"]], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9.73519865353867`"}], "+", 
                    FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}]}], "]"}]}], "\[Equal]", 
        "1"}]],
     Annotation[#, 
      0.5 Log[Abs[-0.021157091589337353` - 
            1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y)/(
            13.694730952998 + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.03315723695712985 + 
            47.265475775695705` (-0.2897406770639119 - 
              0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.017358563477362803` - 
            1425.4950084292877` (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            47.265475775695705` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.12002996286708252` + 
            82120.56316113181 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[
                0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.3031777862580342 - 
            684167.1962530689 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.21567884822807393` + 
            2.256653446472411*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.5220334191228186 - 
            1.0463026230954587`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.8509010091039361 + 
            2.0042828385461956`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-3.9372798220531267` - 
            2.3554829728746694`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[-9.73519865353867 + 
            5.9825135101685105`*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[
                0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[-2.870049975526493 - 
            614524.0300765625 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              0.10272004050338589` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              0.2539824562122541 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
             2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.5671925801862232` - 
              0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.525850871034293 - 
              0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. 
          Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. 
          Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[
                0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y]^(-2) + 
         2234.0252003028777` 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2234.0252003028777` 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[
                0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[
                0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[
                0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[
                0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1. Abs[(-9.73519865353867 + 
              5.9825135101685105`*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 0.2539824562122541 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.1752248373204734` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 57.608453677868795` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
                3.9372798220531267` $CellContext`x + 
                Complex[
                  0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
                Complex[
                  0., -9.73519865353867] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[
               0., -0.5220334191228186] $CellContext`y) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[
               0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-3.9372798220531267` - 
              2.3554829728746694`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.1752248373204734` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                57.608453677868795` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
               3.9372798220531267` $CellContext`x + 
               Complex[
                 0., -3.9372798220531267`] $CellContext`y)) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-3.9372798220531267` - 
             2.3554829728746694`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.8509010091039361 + 
             2.0042828385461956`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[
                0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[
               0., -0.5220334191228186] $CellContext`y) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2] == 1, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], 
       LineBox[{713, 714, 715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 
        725, 726, 727, 728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 
        739, 740, 741, 742, 743, 744, 745, 746, 747, 748, 749, 750, 751, 752, 
        753, 754, 755, 756, 757, 758, 759, 760, 761, 762, 763, 764, 765, 766, 
        767, 768, 769, 770, 771, 772, 773, 774, 775, 776, 777, 778, 779, 780, 
        781, 782, 783, 784, 785, 786, 787}], LineBox[CompressedData["
1:eJwNw+c2AmAAANDP8QpGySgZhYxK2aOMjJQ07CjiV97/n3vPuYneX2M4EkJo
OTYawrgTThox6pQxp51x1jnjJpw36YKLLrlsyrQrrrpmxnU33HTLrDnzbluw
6I677rnvgYceeeyJp5Yse+a5F15a8cprb7y16p01697b8MGmLdt2fPTJZ198
9c13u374ac++X3478Mdf/wEn4Bee
        "]], 
       LineBox[{873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
        885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898, 
        899, 900, 901, 902, 903, 904, 905, 906, 907, 908, 909, 910, 911, 912, 
        913, 914, 915, 916, 917, 918, 919, 920, 921, 922}], 
       LineBox[{923, 924, 925, 926, 927, 928, 929, 930, 931, 932, 933, 934, 
        935, 936, 937, 938, 939, 940, 941, 942, 943, 944, 945, 946, 947, 948, 
        949, 950, 951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 
        963, 964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
        977, 978, 979, 980, 981, 982, 983, 984, 985, 986, 987}], 
       LineBox[{988, 989, 990, 991, 992, 993, 994, 995, 996, 997, 998, 999, 
        1000, 1001, 1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010, 
        1011, 1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020, 1021, 
        1022, 1023, 1024, 1025, 1026}], LineBox[CompressedData["
1:eJwNw+c2AmAAANDPkU3IFikjJHtGIrJ3RshID8D7/3PvOTdV/yv/NoQQajZG
QojYZLMtttpmux122mXUbnvsNWaf/Q446JDDjjhq3DHHTThh0pSTTjntjGln
nXPejAtmXXTJZVdcdc11N9x0y213zLnrnnn3LXjgoUWPPLbkiaeeee6Fl155
7Y233nnvg2UfffLZFyu++ua7VT/89Mtva/5Y9x8uAxaE
        "]]},
      RowBox[{
        RowBox[{"0.5`", " ", 
          RowBox[{"Log", "[", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.021157091589337353`"}], "-", 
                   FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.03315723695712985`"}], "+", 
                   FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.017358563477362803`"}], "-", 
                   FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.12002996286708252`"}], "+", 
                   FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.3031777862580342`"}], "-", 
                   FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.21567884822807393`"}], "+", 
                   FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.5220334191228186`"}], "-", 
                   FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.8509010091039361`"}], "+", 
                   FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "3.9372798220531267`"}], "-", 
                   FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "9.73519865353867`"}], "+", 
                   FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "2.870049975526493`"}], "-", 
                   FractionBox[
                    RowBox[{"614524.0300765625`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              FractionBox["1.`", 
               SuperscriptBox[
                RowBox[{"Abs", "[", 
                  RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], "]"}], "2"]], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9.73519865353867`"}], "+", 
                    FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}]}], "]"}]}], "\[Equal]", 
        "2"}]],
     Annotation[#, 
      0.5 Log[Abs[-0.021157091589337353` - 
            1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y)/(
            13.694730952998 + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.03315723695712985 + 
            47.265475775695705` (-0.2897406770639119 - 
              0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.017358563477362803` - 
            1425.4950084292877` (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            47.265475775695705` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.12002996286708252` + 
            82120.56316113181 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[
                0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.3031777862580342 - 
            684167.1962530689 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.21567884822807393` + 
            2.256653446472411*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.5220334191228186 - 
            1.0463026230954587`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.8509010091039361 + 
            2.0042828385461956`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-3.9372798220531267` - 
            2.3554829728746694`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[-9.73519865353867 + 
            5.9825135101685105`*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[
                0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[-2.870049975526493 - 
            614524.0300765625 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              0.10272004050338589` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              0.2539824562122541 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
             2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.5671925801862232` - 
              0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.525850871034293 - 
              0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. 
          Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. 
          Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[
                0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y]^(-2) + 
         2234.0252003028777` 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2234.0252003028777` 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[
                0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[
                0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[
                0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[
                0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1. Abs[(-9.73519865353867 + 
              5.9825135101685105`*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 0.2539824562122541 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.1752248373204734` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 57.608453677868795` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
                3.9372798220531267` $CellContext`x + 
                Complex[
                  0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
                Complex[
                  0., -9.73519865353867] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[
               0., -0.5220334191228186] $CellContext`y) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[
               0., -0.03315723695712985] $CellContext`y) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-3.9372798220531267` - 
              2.3554829728746694`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.1752248373204734` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                57.608453677868795` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
               3.9372798220531267` $CellContext`x + 
               Complex[
                 0., -3.9372798220531267`] $CellContext`y)) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-3.9372798220531267` - 
             2.3554829728746694`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.8509010091039361 + 
             2.0042828385461956`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[
                0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[
               0., -0.5220334191228186] $CellContext`y) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2] == 2, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {GrayLevel[0], 
       LineBox[{1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1132, 
        1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143, 
        1144, 1145, 1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 
        1155, 1156, 1157, 1158, 1159, 1160, 1161}], 
       LineBox[{1162, 1163, 1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171, 
        1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181, 1182, 
        1183, 1184, 1185, 1186, 1187, 1188}], 
       LineBox[{1189, 1190, 1191, 1192, 1193, 1194, 1195, 1196, 1197, 1198, 
        1199, 1200, 1201, 1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209, 
        1210, 1211, 1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220, 
        1221, 1222, 1223, 1224, 1225, 1226, 1227, 1228, 1229}], 
       LineBox[{1230, 1231, 1232, 1233, 1234, 1235, 1236, 1237, 1238, 1239, 
        1240, 1241, 1242, 1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250, 
        1251, 1252, 1253, 1254}], 
       LineBox[{1255, 1256, 1257, 1258, 1259, 1260, 1261, 1262, 1263, 1264, 
        1265, 1266, 1267, 1268, 1269, 1270, 1271, 1272, 1273, 1274, 1275, 
        1276, 1277, 1278, 1279, 1280, 1281, 1282, 1283}], 
       LineBox[{1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291, 1292, 1293, 
        1294}]},
      RowBox[{
        RowBox[{"0.5`", " ", 
          RowBox[{"Log", "[", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.021157091589337353`"}], "-", 
                   FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.03315723695712985`"}], "+", 
                   FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.017358563477362803`"}], "-", 
                   FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.12002996286708252`"}], "+", 
                   FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.3031777862580342`"}], "-", 
                   FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.21567884822807393`"}], "+", 
                   FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.5220334191228186`"}], "-", 
                   FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.8509010091039361`"}], "+", 
                   FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "3.9372798220531267`"}], "-", 
                   FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "9.73519865353867`"}], "+", 
                   FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "2.870049975526493`"}], "-", 
                   FractionBox[
                    RowBox[{"614524.0300765625`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              FractionBox["1.`", 
               SuperscriptBox[
                RowBox[{"Abs", "[", 
                  RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], "]"}], "2"]], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9.73519865353867`"}], "+", 
                    FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}]}], "]"}]}], "\[Equal]", 
        "3"}]],
     Annotation[#, 
      0.5 Log[Abs[-0.021157091589337353` - 
            1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y)/(
            13.694730952998 + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.03315723695712985 + 
            47.265475775695705` (-0.2897406770639119 - 
              0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.017358563477362803` - 
            1425.4950084292877` (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            47.265475775695705` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.12002996286708252` + 
            82120.56316113181 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.3031777862580342 - 
            684167.1962530689 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.21567884822807393` + 
            2.256653446472411*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.5220334191228186 - 
            1.0463026230954587`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[
               0., -0.21567884822807393`] $CellContext`y) (-2.525850871034293 - 
             0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.8509010091039361 + 
            2.0042828385461956`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-3.9372798220531267` - 
            2.3554829728746694`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[-9.73519865353867 + 
            5.9825135101685105`*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[-2.870049975526493 - 
            614524.0300765625 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              0.10272004050338589` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              0.2539824562122541 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
             2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.5671925801862232` - 
              0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.525850871034293 - 
              0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y]^(-2) + 
         2234.0252003028777` 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2234.0252003028777` 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1. Abs[(-9.73519865353867 + 
              5.9825135101685105`*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 0.2539824562122541 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.1752248373204734` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 57.608453677868795` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
                3.9372798220531267` $CellContext`x + 
                Complex[
                  0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
                Complex[
                  0., -9.73519865353867] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[
               0., -0.5220334191228186] $CellContext`y) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[
                0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[
                0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-3.9372798220531267` - 
              2.3554829728746694`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.1752248373204734` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                57.608453677868795` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
               3.9372798220531267` $CellContext`x + 
               Complex[
                 0., -3.9372798220531267`] $CellContext`y)) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-3.9372798220531267` - 
             2.3554829728746694`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.8509010091039361 + 
             2.0042828385461956`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[
                0., -0.8509010091039361] $CellContext`y) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[
                0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[
               0., -2.870049975526493] $CellContext`y) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2] == 3, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[1, 0, 0], 
       LineBox[{1295, 1296, 1297, 1298, 1299, 1300, 1301, 1302, 1303, 1304, 
        1305, 1306, 1307, 1308, 1309}], 
       LineBox[{1310, 1311, 1312, 1313, 1314, 1315, 1316, 1317, 1318}]},
      RowBox[{
        RowBox[{"0.5`", " ", 
          RowBox[{"Log", "[", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.021157091589337353`"}], "-", 
                   FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.03315723695712985`"}], "+", 
                   FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.017358563477362803`"}], "-", 
                   FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.12002996286708252`"}], "+", 
                   FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.3031777862580342`"}], "-", 
                   FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.21567884822807393`"}], "+", 
                   FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.5220334191228186`"}], "-", 
                   FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.8509010091039361`"}], "+", 
                   FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "3.9372798220531267`"}], "-", 
                   FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "9.73519865353867`"}], "+", 
                   FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "2.870049975526493`"}], "-", 
                   FractionBox[
                    RowBox[{"614524.0300765625`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              FractionBox["1.`", 
               SuperscriptBox[
                RowBox[{"Abs", "[", 
                  RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], "]"}], "2"]], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9.73519865353867`"}], "+", 
                    FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}]}], "]"}]}], "\[Equal]", 
        "4"}]],
     Annotation[#, 
      0.5 Log[Abs[-0.021157091589337353` - 
            1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y)/(
            13.694730952998 + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.03315723695712985 + 
            47.265475775695705` (-0.2897406770639119 - 
              0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.017358563477362803` - 
            1425.4950084292877` (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            47.265475775695705` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.12002996286708252` + 
            82120.56316113181 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.3031777862580342 - 
            684167.1962530689 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.21567884822807393` + 
            2.256653446472411*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.5220334191228186 - 
            1.0463026230954587`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[
               0., -0.21567884822807393`] $CellContext`y) (-2.525850871034293 - 
             0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.8509010091039361 + 
            2.0042828385461956`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-3.9372798220531267` - 
            2.3554829728746694`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[-9.73519865353867 + 
            5.9825135101685105`*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[-2.870049975526493 - 
            614524.0300765625 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              0.10272004050338589` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              0.2539824562122541 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
             2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.5671925801862232` - 
              0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.525850871034293 - 
              0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y]^(-2) + 
         2234.0252003028777` 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2234.0252003028777` 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1. Abs[(-9.73519865353867 + 
              5.9825135101685105`*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 0.2539824562122541 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.1752248373204734` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 57.608453677868795` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
                3.9372798220531267` $CellContext`x + 
                Complex[
                  0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
                Complex[
                  0., -9.73519865353867] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[
               0., -0.5220334191228186] $CellContext`y) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[
                0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[
                0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-3.9372798220531267` - 
              2.3554829728746694`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.1752248373204734` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                57.608453677868795` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
               3.9372798220531267` $CellContext`x + 
               Complex[
                 0., -3.9372798220531267`] $CellContext`y)) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-3.9372798220531267` - 
             2.3554829728746694`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.8509010091039361 + 
             2.0042828385461956`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[
                0., -0.8509010091039361] $CellContext`y) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[
                0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[
               0., -2.870049975526493] $CellContext`y) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2] == 4, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], 
       LineBox[{1319, 1320, 1321, 1322, 1323, 1324, 1325, 1326, 1327}]},
      RowBox[{
        RowBox[{"0.5`", " ", 
          RowBox[{"Log", "[", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.021157091589337353`"}], "-", 
                   FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.03315723695712985`"}], "+", 
                   FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.017358563477362803`"}], "-", 
                   FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.12002996286708252`"}], "+", 
                   FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.3031777862580342`"}], "-", 
                   FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.21567884822807393`"}], "+", 
                   FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.5220334191228186`"}], "-", 
                   FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "0.8509010091039361`"}], "+", 
                   FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "3.9372798220531267`"}], "-", 
                   FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "9.73519865353867`"}], "+", 
                   FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"-", "2.870049975526493`"}], "-", 
                   FractionBox[
                    RowBox[{"614524.0300765625`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              FractionBox["1.`", 
               SuperscriptBox[
                RowBox[{"Abs", "[", 
                  RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], "]"}], "2"]], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2234.0252003028777`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"2.0320360190568152`*^6", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"6.743786893901439`*^9", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.680847524287852`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.092484777475811`*^12", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.0947491790964377`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.017149696890795`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"5.5483000355024906`*^14", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9.73519865353867`"}], "+", 
                    FractionBox[
                    RowBox[{"5.9825135101685105`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"3.579046789934875`*^13", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3.9372798220531267`"}], "-", 
                    FractionBox[
                    RowBox[{"2.3554829728746694`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              RowBox[{"3.776397835415399`*^11", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8509010091039361`"}], "+", 
                    FractionBox[
                    RowBox[{"2.0042828385461956`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5220334191228186`"}], "-", 
                    FractionBox[
                    RowBox[{"1.0463026230954587`*^7", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.21567884822807393`"}], "+", 
                    FractionBox[
                    RowBox[{"2.256653446472411`*^6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.3031777862580342`"}], "-", 
                    FractionBox[
                    RowBox[{"684167.1962530689`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.12002996286708252`"}], "+", 
                    FractionBox[
                    RowBox[{"82120.56316113181`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.017358563477362803`"}], "-", 
                    FractionBox[
                    RowBox[{"1425.4950084292877`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"1.`", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.03315723695712985`"}], "+", 
                    FractionBox[
                    RowBox[{"47.265475775695705`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"]}], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                 RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.021157091589337353`"}], "-", 
                    FractionBox[
                    RowBox[{"1.`", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], "]"}], "2"], "+", 
              RowBox[{"4.584572255884806`*^10", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                   FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.5235226173943955`"}], "-", 
                    RowBox[{"0.017358563477362803`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.017358563477362803`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.2897406770639119`"}], "-", 
                    RowBox[{"0.021157091589337353`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.021157091589337353`", " ", "\[ImaginaryI]"}]}],
                     ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.5671925801862232`"}], "-", 
                    RowBox[{"0.03315723695712985`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.03315723695712985`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6.914740555784635`"}], "-", 
                    RowBox[{"0.12002996286708252`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.12002996286708252`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.7113939675135366`"}], "-", 
                    RowBox[{"0.21567884822807393`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.21567884822807393`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.525850871034293`"}], "-", 
                    RowBox[{"0.3031777862580342`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.3031777862580342`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.4204200987330196`"}], "-", 
                    RowBox[{"0.5220334191228186`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.5220334191228186`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.6299742084208309`"}], "-", 
                    RowBox[{"0.8509010091039361`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"0.8509010091039361`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.29481164973282303`"}], "-", 
                    RowBox[{"2.870049975526493`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"2.870049975526493`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4.627189038357568`"}], "-", 
                    RowBox[{"3.9372798220531267`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"3.9372798220531267`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2.472569665739981`"}], "-", 
                    RowBox[{"9.73519865353867`", " ", "x"}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"9.73519865353867`", " ", "\[ImaginaryI]"}]}], 
                    ")"}], " ", "y"}]}], ")"}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.10272004050338589`", "\[InvisibleSpace]"}], 
                    "+", "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2539824562122541`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.3484259885811069`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.1752248373204734`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1.9155861739279385`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3.298394688946311`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4.6365232762302675`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8.331253098089926`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"13.694730952998`", "\[InvisibleSpace]"}], "+", 
                    "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"30.159328453481663`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"47.265475775695705`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"57.608453677868795`", "\[InvisibleSpace]"}], "+",
                     "x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.`", "\[InvisibleSpace]"}], "+", 
                    RowBox[{"1.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
                    "y"}]}], ")"}]}]], "]"}], "2"]}]}], "]"}]}], "\[Equal]", 
        "5"}]],
     Annotation[#, 
      0.5 Log[Abs[-0.021157091589337353` - 
            1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y)/(
            13.694730952998 + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.03315723695712985 + 
            47.265475775695705` (-0.2897406770639119 - 
              0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.017358563477362803` - 
            1425.4950084292877` (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            47.265475775695705` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.12002996286708252` + 
            82120.56316113181 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.3031777862580342 - 
            684167.1962530689 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.21567884822807393` + 
            2.256653446472411*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.5220334191228186 - 
            1.0463026230954587`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[
               0., -0.21567884822807393`] $CellContext`y) (-2.525850871034293 - 
             0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1)/(
            57.608453677868795` + $CellContext`x + 
            Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-0.8509010091039361 + 
            2.0042828385461956`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         Abs[-3.9372798220531267` - 
            2.3554829728746694`*^7 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[-9.73519865353867 + 
            5.9825135101685105`*^6 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[-2.870049975526493 - 
            614524.0300765625 (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
             Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) (
              0.10272004050338589` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              0.2539824562122541 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.1752248373204734` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              1.9155861739279385` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              3.298394688946311 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              4.6365232762302675` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              8.331253098089926 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              30.159328453481663` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
             2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.5671925801862232` - 
              0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.525850871034293 - 
              0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y)]^2 + 
         1. Abs[13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y]^(-2) + 
         2234.0252003028777` 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2234.0252003028777` 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         2.0320360190568152`*^6 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         6.743786893901439*^9 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.680847524287852*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.092484777475811*^12 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1.0947491790964377`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.017149696890795*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         5.5483000355024906`*^14 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[
                0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)]^2 + 
         1. Abs[(-9.73519865353867 + 
              5.9825135101685105`*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 0.2539824562122541 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.1752248373204734` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 57.608453677868795` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
                3.9372798220531267` $CellContext`x + 
                Complex[
                  0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
                Complex[
                  0., -9.73519865353867] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[
               0., -0.5220334191228186] $CellContext`y) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[
                0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[
                0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.579046789934875*^13 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)]^2 + 
         1. Abs[(-3.9372798220531267` - 
              2.3554829728746694`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.1752248373204734` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                57.608453677868795` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
               3.9372798220531267` $CellContext`x + 
               Complex[
                 0., -3.9372798220531267`] $CellContext`y)) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-3.9372798220531267` - 
             2.3554829728746694`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y)) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.8509010091039361 + 
             2.0042828385461956`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[
                 0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
               Complex[0., -0.8509010091039361] $CellContext`y) (
                1.9155861739279385` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.5220334191228186 - 
              1.0463026230954587`*^7 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[
                 0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
               Complex[0., -0.5220334191228186] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                4.6365232762302675` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
              0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.21567884822807393` + 
             2.256653446472411*^6 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
               Complex[
                 0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                3.298394688946311 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
             0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.3031777862580342 - 
              684167.1962530689 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[
                 0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
               Complex[0., -0.3031777862580342] $CellContext`y) (
                8.331253098089926 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.12002996286708252` + 
             82120.56316113181 (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[
                 0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
               Complex[0., -0.12002996286708252`] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                47.265475775695705` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              57.608453677868795` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.017358563477362803` - 
              1425.4950084292877` (-0.5235226173943955 - 
               0.017358563477362803` $CellContext`x + 
               Complex[
                 0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1) (
                30.159328453481663` + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
              0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.03315723695712985 + 
             47.265475775695705` (-0.2897406770639119 - 
               0.021157091589337353` $CellContext`x + 
               Complex[
                 0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
               Complex[0., -0.03315723695712985] $CellContext`y) (
                13.694730952998 + $CellContext`x + 
                Complex[0., 1.] $CellContext`y)^(-1)/(
              47.265475775695705` + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.021157091589337353` - 
              1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
               Complex[0., -0.021157091589337353`] $CellContext`y)/(
              13.694730952998 + $CellContext`x + 
              Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[
                0., -0.8509010091039361] $CellContext`y) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         3.776397835415399*^11 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-4.627189038357568 - 
              3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.8509010091039361 + 
              2.0042828385461956`*^7 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[
                  0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
                Complex[
                  0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
                Complex[0., -0.8509010091039361] $CellContext`y) (
                 1.9155861739279385` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 4.6365232762302675` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.5220334191228186 - 
             1.0463026230954587`*^7 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-1.6299742084208309` - 
             0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.21567884822807393` + 
              2.256653446472411*^6 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[
                  0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
                Complex[
                  0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
                Complex[0., -0.3031777862580342] $CellContext`y) (
                 3.298394688946311 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 8.331253098089926 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-2.4204200987330196` - 
              0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.3031777862580342 - 
             684167.1962530689 (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             57.608453677868795` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
             0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.12002996286708252` + 
              82120.56316113181 (-0.5235226173943955 - 
                0.017358563477362803` $CellContext`x + 
                Complex[
                  0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[
                  0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
                Complex[0., -0.12002996286708252`] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 30.159328453481663` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1) (
                 47.265475775695705` + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.7113939675135366 - 
              0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.017358563477362803` - 
             1425.4950084292877` (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[
                0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1)/(
             47.265475775695705` + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-6.914740555784635 - 
             0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         1. Abs[(-0.03315723695712985 + 
              47.265475775695705` (-0.2897406770639119 - 
                0.021157091589337353` $CellContext`x + 
                Complex[
                  0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
                Complex[0., -0.03315723695712985] $CellContext`y) (
                 13.694730952998 + $CellContext`x + 
                 Complex[0., 1.] $CellContext`y)^(-1)/(
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
              0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[
                0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         Abs[(-0.021157091589337353` - 
             1. (-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y)/(
             13.694730952998 + $CellContext`x + 
             Complex[0., 1.] $CellContext`y)) (-0.5235226173943955 - 
             0.017358563477362803` $CellContext`x + 
             Complex[0., -0.017358563477362803`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
             Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
             Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
             Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
             Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
             Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
             Complex[0., -0.8509010091039361] $CellContext`y) \
(-0.29481164973282303` - 2.870049975526493 $CellContext`x + 
             Complex[
               0., -2.870049975526493] $CellContext`y) (-4.627189038357568 - 
             3.9372798220531267` $CellContext`x + 
             Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
             Complex[0., -9.73519865353867] $CellContext`y)]^2 + 
         4.584572255884806*^10 
          Abs[(-0.5235226173943955 - 0.017358563477362803` $CellContext`x + 
              Complex[0., -0.017358563477362803`] $CellContext`y) \
(-0.2897406770639119 - 0.021157091589337353` $CellContext`x + 
              Complex[0., -0.021157091589337353`] $CellContext`y) \
(-1.5671925801862232` - 0.03315723695712985 $CellContext`x + 
              Complex[0., -0.03315723695712985] $CellContext`y) \
(-6.914740555784635 - 0.12002996286708252` $CellContext`x + 
              Complex[0., -0.12002996286708252`] $CellContext`y) \
(-0.7113939675135366 - 0.21567884822807393` $CellContext`x + 
              Complex[0., -0.21567884822807393`] $CellContext`y) \
(-2.525850871034293 - 0.3031777862580342 $CellContext`x + 
              Complex[0., -0.3031777862580342] $CellContext`y) \
(-2.4204200987330196` - 0.5220334191228186 $CellContext`x + 
              Complex[0., -0.5220334191228186] $CellContext`y) \
(-1.6299742084208309` - 0.8509010091039361 $CellContext`x + 
              Complex[0., -0.8509010091039361] $CellContext`y) (
               0.10272004050338589` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.2539824562122541 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               0.3484259885811069 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.1752248373204734` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               1.9155861739279385` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               3.298394688946311 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               4.6365232762302675` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               8.331253098089926 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               13.694730952998 + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               30.159328453481663` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               47.265475775695705` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (
               57.608453677868795` + $CellContext`x + 
               Complex[0., 1.] $CellContext`y)^(-1) (-0.29481164973282303` - 
              2.870049975526493 $CellContext`x + 
              Complex[0., -2.870049975526493] $CellContext`y) \
(-4.627189038357568 - 3.9372798220531267` $CellContext`x + 
              Complex[0., -3.9372798220531267`] $CellContext`y) \
(-2.472569665739981 - 9.73519865353867 $CellContext`x + 
              Complex[0., -9.73519865353867] $CellContext`y)]^2] == 5, 
      "Tooltip"]& ], {}, {}, {}, 
    TagBox[
     TooltipBox[
      {GrayLevel[0], LineBox[CompressedData["
1:eJwNw1VWQlEAAMDrhwthBwa2gh3YIHY+C5Wwu7tQ2bEz50wsKqWLVSGEyJrq
EGqts964DTbaZLMtttpmux0mTNppl9322Guf/Q446JAphx1x1DHHnXDStBmn
zDrtjLPOOe+Ciy657Iqrrhm57oabbrltzh133TNvwaIl9z3w0COPPfHUM8+9
8NIrr73x1jvvffDRJ5998dU33/3w0y+/Lfvjr39W/AeJIyjx
        "]]},
      RowBox[{"x", "\[Equal]", "0"}]],
     Annotation[#, $CellContext`x == 0, "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  PlotRange->{{-64, 2}, {-15, 15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.473217061409865*^9, 3.473217093098486*^9}, {
   3.473217303432575*^9, 3.473217320881686*^9}, {3.473217365921249*^9, 
   3.473217388376687*^9}, {3.473217420873508*^9, 3.473217434493148*^9}, {
   3.473217556224373*^9, 3.473217628199096*^9}, 3.473217664707589*^9, {
   3.473217712748689*^9, 3.473217862231311*^9}, 3.473218213303213*^9, 
   3.473218410340289*^9, {3.473218717992518*^9, 3.473218825308485*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Decay", " ", "problem"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"-", "m"}]}], ";", " ", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"n", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "i"}], "]"}], "]"}], "=", 
       RowBox[{"x", "+", 
        RowBox[{"I", " ", "y"}], "+", 
        RowBox[{"n", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "i"}], "]"}], "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "nd"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", "n", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"id", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "nd"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "nd"}], "}"}]}], "]"}]}], ";", " ", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"id", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "i"}], "]"}], "]"}], "=", "1"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "nd"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"expn", "=", 
     RowBox[{"MatrixExp", "[", 
      RowBox[{"n", " ", "t"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"v", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Random", "[", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "nd"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"v", "=", 
    RowBox[{"v", "/", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"v", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "nd"}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"w", "=", 
     RowBox[{"expn", ".", "v"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"z", "=", 
     RowBox[{"w", "/", "v"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"z", " ", "/.", " ", 
    RowBox[{"t", " ", "\[Rule]", " ", "1"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"z", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "nd"}], "}"}]}], "]"}], " ", "/.", " ", 
    RowBox[{"t", " ", "\[Rule]", " ", "1"}]}], "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{"z", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "20"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.473218072059788*^9, 3.473218192538309*^9}, {
  3.473218224730501*^9, 3.473218349997146*^9}, {3.473218586389472*^9, 
  3.473218598112169*^9}, {3.473218633471727*^9, 3.473218634980366*^9}, {
  3.473218675332705*^9, 3.473218676855958*^9}, {3.473218856051309*^9, 
  3.473218861528538*^9}, {3.473218946061863*^9, 3.473219167025632*^9}, {
  3.473219199539803*^9, 3.473219207579094*^9}, {3.473219253390793*^9, 
  3.473219430065033*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.3484259885811069`"}], "0", "0", "0", "0", "0", "0", "0",
       "0", "0", "0", "0"},
     {"0.3484259885811069`", 
      RowBox[{"-", "0.10272004050338589`"}], "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0"},
     {"0", "0.10272004050338589`", 
      RowBox[{"-", "0.2539824562122541`"}], "0", "0", "0", "0", "0", "0", "0",
       "0", "0"},
     {"0", "0", "0.2539824562122541`", 
      RowBox[{"-", "1.1752248373204734`"}], "0", "0", "0", "0", "0", "0", "0",
       "0"},
     {"0", "0", "0", "1.1752248373204734`", 
      RowBox[{"-", "1.9155861739279385`"}], "0", "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "1.9155861739279385`", 
      RowBox[{"-", "4.6365232762302675`"}], "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "4.6365232762302675`", 
      RowBox[{"-", "3.298394688946311`"}], "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "3.298394688946311`", 
      RowBox[{"-", "8.331253098089926`"}], "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "8.331253098089926`", 
      RowBox[{"-", "57.608453677868795`"}], "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "57.608453677868795`", 
      RowBox[{"-", "30.159328453481663`"}], "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "30.159328453481663`", 
      RowBox[{"-", "47.265475775695705`"}], "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "47.265475775695705`", 
      RowBox[{"-", "13.694730952998`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.47321886316962*^9, {3.473219027043924*^9, 3.473219096810546*^9}, {
   3.473219131776911*^9, 3.473219167781952*^9}, 3.473219208107627*^9, {
   3.473219254641157*^9, 3.473219265489365*^9}, {3.473219297494573*^9, 
   3.473219431016476*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1733354730206551`", ",", "0.10127531605890513`", ",", 
   "0.14926737000162024`", ",", "0.11171743534853307`", ",", 
   "0.04946605930736051`", ",", "0.024841250762236564`", ",", 
   "0.05522327428035706`", ",", "0.015480479893733945`", ",", 
   "0.048706198814309314`", ",", "0.1581323669225275`", ",", 
   "0.0726546928079844`", ",", "0.03990008278177731`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.47321886316962*^9, {3.473219027043924*^9, 3.473219096810546*^9}, {
   3.473219131776911*^9, 3.473219167781952*^9}, 3.473219208107627*^9, {
   3.473219254641157*^9, 3.473219265489365*^9}, {3.473219297494573*^9, 
   3.473219431020909*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.7057981502134536`", ",", "1.3794924868193925`", ",", 
   "0.8505191569413715`", ",", "0.48954107833372534`", ",", 
   "0.888148565829516`", ",", "0.7937191361182291`", ",", 
   "0.5561610392584282`", ",", "0.8173051007714878`", ",", 
   "0.03778049354612951`", ",", "0.022472528734181117`", ",", 
   "0.031429781755054884`", ",", "0.20274691487514113`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.47321886316962*^9, {3.473219027043924*^9, 3.473219096810546*^9}, {
   3.473219131776911*^9, 3.473219167781952*^9}, 3.473219208107627*^9, {
   3.473219254641157*^9, 3.473219265489365*^9}, {3.473219297494573*^9, 
   3.473219431023351*^9}}],

Cell[BoxData["6.77511443319611`"], "Output",
 CellChangeTimes->{
  3.47321886316962*^9, {3.473219027043924*^9, 3.473219096810546*^9}, {
   3.473219131776911*^9, 3.473219167781952*^9}, 3.473219208107627*^9, {
   3.473219254641157*^9, 3.473219265489365*^9}, {3.473219297494573*^9, 
   3.473219431025582*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVx3080wkcwPGVp0uIvOoqZxvJMo/rd9cr91Lfb6lXQrZ5yN28ejCMy1Pt
7PLU066FrtU6Xgo5SblbRVzIQwlhka00T4eOw0qea7eyeLXr/vi83q+PDTfe
P2IpiUTa+7n/zT/BNWSE52175lB8T6ebhWYl1TeYmgSUisoI4cws6Frrf6ZS
M+CA4kWx2ctZyG8QUwyoObC3z7/Rs3YWYrYKYj9QpLCsr7uFIpgF5UJU1hyl
BgTe4ozcqRkwGhihTVPa4MSQ+MdjI9NQ2F5wdJLyFyQHGR6vG5+E0rsZAzEu
E3BfnlRpbj4OkdCZM8VXwyfHnzTn1WMQp3IYrSjVwh5m2m+13iNgbHOGNrSF
hKLsYHdy5hBcMH9KLzykh1dFLZkoGgDuQOAjvQ5DXCSiB3hVvXC05Qw3nmaM
O9t3l95K7YLyIyYBa/aYInPyrQNpuBMKU6In3ILNMc7Iz0/ZrQBhwSL73ykL
dN0qbu0faAeSchgfJFtiFeNkNV8gA/sEXmIgfRWm2Jp+4b69GcY0l/ctf7ga
O+NJAR7SRvBWHT7+69E1KPqBlc/h14PfmMSRTF6Hyd/vnHnCqoWJx9xTT0qs
8OGd7S6b56vAxaLH2vOgNXYlXfTo6bwHxqAJHVSTcUV539Ldu8ph9zTng20Q
FeV1BZEbGkugryl8CcfJBucoOU28e1KoTG8+QNV8/vSvRRuji4FnIBhWKGyx
z+bLXnVgEYTxUypNctcjP0HbVtZ9DVwjHRW+oXZouNB+KZqXD89WOi0XuG/A
5wmCmL8P5UBdqTDPSc8e17Pvp6VTsiFlCZ3V8dIezcbS1141zwTjwWSvuAoa
6vgyp5AkCaiKbbIKUjeiwXpZHL/hPGRtXKtfE+SAXg4+qrPydJDk8mShVDqa
h0nnzuWJgJO1X2Hymo7VMw1DxsNCmN95U1tQ74gZyv1HqnxPwahqR2JTmhPG
TtbRX8amwvWtDCt5qDNWiw+v8hQmQolIYBHp7IK3OGtiEvcJIC0ozEdP44Lj
hWX8m9f48M1goTRN7or+UUbyAMsjcMUhr0Tu44ZdLVl5TgYxcLJBfMWnxg3N
bDvPLbeLgr1WQTfb7Rio6rSMUfWHw/Y4WYhFBgPJFw16ZQwuFHzFtevQMJC0
X/l+A/cg2D3+PdsvZBNW25p+FxsUAhLnJvqL+k2YV5ZIXzEUDDy1fmcbncCw
J+tSJvICgVv+jppxkUCKR0PayAc2xAgDFr0vESja1S5UTbFBEFDRa5JJoNLf
avPsP2xI1wguSLIJ9HptV7m6gw2l7tqFy/kERoSGXa+8xgZto66n+DaBd3ps
S1192CB5YSJulhH4Tr6sbP4GC3KLYqPOthHYZ352uj2XBUUJCk+vpwQOvskI
L5KwoGq15ONTBYGyP+ZmeaksGORYRim7CeTwN6/cEsgC2uhaz5FRAqnjlh46
fRa4VSSTb6gIrLHMusp7z4RvRQPaiNcE2j+KfNA/wgRfWn7ZmwkCe6M+Pn9V
xwR+NJX89i2B/evqTovjmJDqcVr7p5pAtjOjMjCECSLTka4EDYFnWqekNC8m
XLlb9Mv8PIGKlmO1czZMuH5KP7L2I4G6JrXslRkTbrMjdqQuEvg+3ix5fMEP
Kmxbrbd9IpBkJG3TjPtBvdpeq9MRaG0tvWvW4wf/AYBERc0=
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], 
    LineBox[{{4.0816326530612243`*^-7, 1.0000002014777616`}, {
     0.006134358411192534, 1.0030231858378738`}, {0.012268308659119763`, 
     1.006036467408259}, {0.02453620915497422, 1.0120340131753123`}, {
     0.04907201014668314, 1.0239136693953423`}, {0.09814361213010096, 
     1.0472162725004022`}, {0.19628681609693663`, 1.0920342411305777`}, {
     0.23202361771822136`, 1.1071080174007926`}}], LineBox[CompressedData["
1:eJwB8QIO/SFib1JlAgAAAC4AAAACAAAAVumVd7bqJEBKA37ltrbxP88SLAt1
OSVA7XbMhb548T+7roKbLAMmQIfg0sct3fA/ewEqUMzdJkAjrlM9YzjwPwrc
ekhutCdAm6nhiXU17z/lpiGUn3woQME+YhMUF+4/lCgZBLlVKUDpdWJVNens
P5CaZsdhICpANBgrdL/X6z9alF3ODOcqQOBrvrGR0+o/+ESl+Z++K0CyUEaV
IMLpP+PlQnjChyxA7dXzY1HL6D+iPTEbzWEtQMhoyP7DyOc/rYV1EWctLkBS
NphUst/mP4dVY0sD9S5ALxGO/eoC5j813KGph80vQAaBvK/tG+U/mCmbrc1L
MEDw7celJkzkP3/AjZhLuTBAka2auUxz4z9NG1WlyiQxQHtJFmCYpuI/QW7H
WxGJMUD6mlSXwu7hP58cYiTM9TFA8aJWhfgu4T8kw6eWTlsyQGD+vrDKguA/
kC3CKtK+MkBDpbYpfcDfP2bzBNHJKjNAYAh2xVNt3j9isfIgiY8zQEa4qN0m
Pd0/bIJT/EqRM0BBP6EI8zfdP3VTtNcMkzNAueFrGMAy3T+I9XWOkJYzQOBy
7uVcKN0/rjn5+5edM0BdBeo0oRPdP/nB/9amqzNADTDLhFTq3D+Q0gyNxMcz
QLtaH/1kmNw/mqNtaIbJM0DoIiGATZPcP6N0zkNIyzNATJew4zaO3D+2FpD6
y84zQM+A8EsMhNw/3FoTaNPVM0AttTydwW/cPyfjGUPi4zNALMJQJVZH3D8w
tHoepOUzQHpeQaFMQtw/OoXb+WXnM0DhlaD7Qz3cP0wnnbDp6jNA618jSzUz
3D9yayAe8fEzQPWlhlEiH9w/fDyB+bLzM0BsUDi9HxrcP4UN4tR09TNAbOVJ
Bh4V3D+Yr6OL+PgzQKKiBTAdC9w/ooAEZ7r6M0CIOmwQHgbcP6tRZUJ8/DNA
VZyrzR8B3D+0IsYdPv4zQMUFomci/Ns/vvMm+f//M0Doti3eJffbP8ijZmM=

     "]]}, 
   {Hue[0.14213595499957954`, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzXk41AkYwHGlYx/Gg5QjYZQM4/aLxcb7lq2EtEIsT2LK0TpaMg8hlSNm
oxWTHDtZ2a6nnKEolJSfa1xlaCa3lEyTJsuIbPvH9/n++dFmnDwUsFpKSsrt
e/+fk8BYZ3a8wI4u4PBWVkTQ3Ed19qSeBtfgJsaTf0Ww8qIhiUplQZLggmuq
UAScJxlaa6l5wGcN79XjiyDUlhk2r3UHRmU3UWpqRND3NZj9SasWlr/YTC6F
i2A9f4wm1GoFU2V3jsrERyhqK4z4oDUIof6eKaxhIXzJraYPpw/C5fu1Uyo8
IewNah/vlQyCxJ53/h5XCDPS8x51fa/hplynw7t6IVjZutiwUgXgVW+Zfecv
IXSXLa2miYaByVyudPERwtk2Q0ezo+Pw4rbgttSbGSgtY/FDjadB3lgq9eun
DxAEPXkzkWIYCRIviUKnIXxSf7yqVALNp0S0b3rvQUY7mTZsJYVplbtGVZan
4JJCO73ITxrZyxbrTlCmgMF3b5TuWIfRzmlDXfpvIeJ5MuMkTQbLl2oDxIGT
UPE7xU11vxzqNh9Mut88AUVxIdOmngrY5Ju4KXH7BCQWLrl+mVHER+lWpBVn
HKT6RvBxrBIW/PF2Pp86DrpRgTHu9E0op8LfblA0BhNzVw/L1ivj+8YrvgMm
Y+A4+duZrAhVrFivw8upHQWXiUwDTc3NqOQS3T/nMArTzxjnyBJ1/DFnc5zV
2AgYK/Zr2B/VQMZ5LafbUSMgA3P+ArEmBrGHNtfKj8A+off8Vg8q1qmriGf3
DsNA0/FV3obauF/YpmkTNQTVac2+1DltBIWP7hsr3kDgWuYIl7sVjcLz4xaG
BHAsMq6akr8Ns3aWrjbfIgCTIAOus78ORmYplhb58qFrg6Es03o7sqejVUuy
XsOj0sQCQ2ldpLjklav1D0LcKvovHW908YdG9aM82UGQEcQ6hFfRMFpbaf+N
fQMweVObXRivh1lsE/mFLB6w9dTW1Hro42KgOLWlpx8y8wNb/Kl0zBarOVlQ
+8GbfYRLmaLjNrWpXyejXsHCzzckhQ0GaJmepLWn4SWMT+6OaUo1xLe25wKU
VV7CdVsz9U5/I2xU23HpbEAflKQwFYOMjLH33qKm5bNeSPU45iQ9Z4z1TD1u
Mq0XLARFd1I7TfBQQ8ffFxN7IFe/oKTTyRQ51gdPuMx0w9knGblOtaYof0VQ
eu1ANxxQ97jRpmOGUjWDqhtCu2BXeIuPIssM7eP5Zn1eXCjcwtDpmDNDP2az
fbFlJ+g8u5Xj4mOOrPQ6jRiTDsg0aqL3Npij/gaLM9U72iFQvKanlU5gWd5n
+UrDNmBUfKay/iRwJcTDrs+2FUIT3ZYcLxO4e3Tj7EPrVmC6VfEo2QRWd/iY
F1q0Qtoc81JmDoH0Kn+/MKNWKLWWfL3KIVA+IuaEgkYrSJ6u9N+8S2DIA2X9
iCUSMnspGc0tBKYr2NE4j0jILw4LvtBKYH32cAH7AQnFUVx7h3YCebco19Lv
k1CjnLnYziVw5/N3jgl3SRB4KwX3vSLwalHTnuACEmjjavZj49+9jY8fHo4j
wbQqVvOfSQLjeJarPaNJsEnhSwKmCMzQeDjgeYoEZxqn/P00gbou9wx9QkiI
DKFqzs4SmEwJOxnsQ0L8zvOSSvF3r9uIGuZJQorc2MuoOQJHXpcfiXQjIbes
+OLCAoHmh/gJCU4kXD+3JqhukcDTsRGMlH0k3HUN2B2/ROCw363edHsSqra+
0LD7RqCxV1QXG0hoEOtKVlYIfFra5cX5iYT/AHYlgPQ=
     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJwVkmk4FAobQDHZU2PctNq3kK1pkeJ9SyprUlpUXCpEKYWaSG5IilJJ4kpU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     "]]}, 
   {Hue[0.6142719099991583, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlnc81f8Xx68tIyu+KeOSkZF1NSTOuySRVCKjaWSVFQoppZBQSELZ0RBK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     "]]}, 
   {Hue[0.8503398874989481, 0.6, 0.6], LineBox[CompressedData["
1:eJwVVnc81f0ftTPjWg+yhWy5ekTq/SktI0oUDcpW8UTIigZdCtmPlhHVkxXX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     "]]}, 
   {Hue[0.08640786499873876, 0.6, 0.6], LineBox[CompressedData["
1:eJwVk3c4FYwfxa2bvaMks7jZ4/YmVN9vmSGVnYYSbgMhhJREXXqtIpSQVO9V
ZkZIinvtkb2TdW0JKVL8+v1xnvOc5/PHOf8cGccrFs4sTExMn//q/55803GT
hlPSAbbX+GN9Yx7o7dJmttL+kM28Cy7S5mGjujxEWjocpojE0nuUeUj+GClF
kH4ExiekNP4IzoPrfh+3n1IZYJn1RalT7Svkdww9/66XCUl2/U7qq3Pw67LZ
wAI5BxgWd7yO0uZAv+m+3I/uN3BSyZ3Wd2IO2tcuxH2TKoG65OdOxJhZ8K2R
VJ/PKwVZprE/6Q6zsC22o2FOrwwWcjK3j6rNgqMiss6QPwB7ip7Ri7YZ8Mvk
LlnsroSeDzosYjIzwN4/QpyTqoNM8YOd5KEp6Pn43md2sg6O1wyXkd9NwauX
ibSZvHpoSUg9L5AwBeZe5g7Teo2wlz1A1fLYFMRzlsZPkD+BZoVrrEP9JBRc
M/G6urUFPI0mkl1eTcKTaS2xpcAWeL95WJrt30lwbxEiLxq0Ql6lIfvqkUkQ
elLLstDdBkXLvVsofROwxleU4bGvHfRitarWyydgLDj92Len7ZDPcT13NX0C
isg3U+YvdkCuLuPZlSsTYE/arfN1rRMEM29sEeOZgLT6VM8ZqV6oe2Lbbm0/
Dt8TCxW/RPRCaY2pDkl/HAzJDaNtq70waed3IEh1HGZZf1qXtvdB2R3bvXZs
47B3v7lOOGUATpv2xtAKGPAvt9NS4PcB0A9eNGxIY8Bgr3+mx7nPsEvzTZFy
NANCfV9I2ukOwm0Be9alSwxoyfnNQpz/AoHL7Nqm8gwQAs4zvKpDYBUUdXZQ
hAG68nE6FKchKKk+SismMCDqe8ZSQOsQWB8xLNEZH4Pd9zudHV8Pw0O+QgGd
V2MQVK9souEwChlLUacC940BNe+t/OuHo2D9QDAvUW0M2hIPsco1joIS0e7t
oOwY7CTblW3VHoMA37WqYc4xqGcNVWUSZkDSs4rTSb2jILq/X+hT9Tj4Dzff
LLg5Ctk54f2uqtNQ9jhCZLh7BKaFpiNMzk1DtalFQljzCBB9TQ7sipuGzfGm
Z7WqRuDpPu600dVpkFhZbaa+GYEHdREu9lUzsK66QGqOHAHf0egFo1NzEOi8
pl2rPwKp3A0hggbfwFf42tvj+cNAhtZHs15LEOqh0dITPgTuDIXRguxVECD/
573DegCGzvRyVNStgs266+ITHADLnjDVprFV2Igc0xdXHoC9DRP+jG2/YPHA
+h4i6wCw5r0QEKX8gpfkbyPBef2QGChz4JrDGjw8rHvXjb8fKoTFHmkL/IFK
Pd/tZ1p7gUsmlPhlLxO6ef/HPenTDbX77qvdNGBC6/oWXWHnbrhrl6IlYcGE
S4wP10ysuoElptjo5GUmLGiUP/ZZsxt+rc+Su5OZMG9STDz+WxfMDFhTP7Ew
Y7yCW5aDexc0JhIVPjYyY/igbmTy1U64V7Bbw6GXGdvSvx0+59QJxi0HtdcZ
zBjDtMdG07oT6OynDu/bYEaFaD3P33s6ocw35mKxBgumOy8oa6x1QJbVakZu
PAtGmui8k7rbAVECDYppZ1nxibd0wPaX7VCiJVFo7s6KrKbknW4J7TB25gr8
vs6KXvzcqU1h7aCbJWxlm8CKzCf8Vt9fbofJw6du8DazolHdo+GTmn9/FjL3
yV+XDRfYd+SFVbbByjK/j4UoAR+mKQ0Hfm2FHRKOGxs7CJh80Cz9/XArmOsX
hGdpELCVSL7C29kKLx7YpXAcIWD+DlnmvnetYKGWVlMeQkADHwM2+XutkHVB
c5vSAgGd8pjmbim0gmO/1QfWxk34UuRx0U+vFuBKGnbz7N2EiV2/+/ZeaIE3
9u7bv4xvwqo5eU3K6RZg7aP4lzKzI2tyjYmpcQs87ykleWqxY6wK19AVyRYY
75SmDj5jx914LxYff4JLLbMxJf4cKBPlZBpLbgahGH8gUjgwvOpfsd3WzVB6
dNPXuDgOvKrBazx7qBm4P0mZeuRwYNa9u47PJJshs8mCQGRw4GCzR7tsdxN8
rS/2jzvGiWOlsy1nzJrAsyrU8QqRC7OZT09tNmoEyTHDTT9IXHjn6I7FG3sb
oYGF81UgcqFljtrTFYVGkMPIhfATXNhkV/1ElrcReksf3nr+Lxe69p74atjR
AAdzX6b0znMhd0Z/5QfnBhBMqu3TK+ZG8W2k/Om4eigvuXezns6NCcwaLx3D
6uFyj5ns8VZujDK265q6Xg9VIq0Xz0xzo9kPmedy5+vBP6Z3xW87D1qnBC4e
06yH4TvTotm3eFAoOMDNpb0O8jx4LLce5sXi2ik7Aek6aHws7J9lw4uqM5LG
zpvrYJy+LfWQEy/uWxIIq+Oog21iCjOuQbxognwvPizUQmiFQUhFIS8yzx5h
O0uvBRuhoPxLsnw4W5Qi5+BaC7/yF4Tfr/FhUEh/T111DWweXNG24OTHmcMh
B4bLakCVg+nshCg/jlMu+BDya+D8Kb5MQU1+ZFkv5vFOrYFGNiV9lwv8yOXx
eXDCrwZSrJ28+Tv5MSHkpP421RpIu355Wt1WAC//OSujnlYN6h85VyinBfBP
h1yi+aNq+MhGJXw5L4B518De9341DEWOSUd6COBxvvqI4eBqkHx62nYqXADn
aZIGcuer4TH9KD2tTAA3tLQItsRqeMC7O0VIVhDP0EU3+IqqQNai7fXFXYJI
DMllgpwqyIv3KPmoKojnbSqbfKlV0CKV1eGuK4gxPTopfx5XAZ+mPHeDlSAa
eIhPuNyqgns2W/1CKIKoUc9XlmJWBbdTfx//PiuIXQeXXE5O0+GYerGn0pIg
OjlL6UeN0UGy4up9x1VBrLStdq4ZpEPpyHRLC0EIs22cLM3a6bAo13s0S1II
QzWjx1LL6OCYWXjE5ZgQCujxXnKJocPBEvfDPflCSD7/O1NrHx34TBQv8pcK
4Xxo2JysFh0G+hhhhh//8kcCV4Q16eD3+1RtQaMQDmT5bmHbRYdcMDW6zxDC
boFQ9R2b6SBdTTQw2SKM9S0TuhZzNGBqH8KyAGHss7MP0EunQehUeVpAsDDS
nm9lvpBCA06mZBbtMGE0MHpYeP8RDYRUTtALHwpj9Dx/2PdoGshRWo1ycoUx
Ylfyzx+BNDDRrTR/Ni6MWZF5ZpO2NIhNTz8VZrEZTY4bUg4L0kDe28XPSlEE
M1jX90fHVIKKzhfLVHURLM79SuaIrITdTHZq03tE8Lf5teeh4ZVwKOLweJCe
CEZ59+jdvV0JZ54rW70+9Te//fksy7sS4jsW1ViiRVD7toR6+IlKIPwTNJGz
JIKPLnKo2cpVwthygg33e1GkPE24d5NeAc8Okq5+pomigsTiiENFBThENkfn
1IvipodHaHrlFdC3k1Bn2SOKrwgveYSLK6DV0kv3yZIorqmE2X56XQHleWbS
KopbUH+cEP0utgIS3JinzRO2YKkCqfSwcwWYMC7deOC5FSkz4pJhfBVgPhaj
JCm5DW0M9gZ5XfsI0zTHW7VZ4th07yzX1Z8fQFWwS0LPQQI5b0XJ3iJ8AC5Y
PjewJImKLyiRF/4pB6M5+5+y1tL4Iv67Z+6599BT6cRsryyDzgozW9qSyqAw
jH5GelkGY5c3tWdPvQMXgs9Qc7Msxn1bcn6j8g7Oe10v5Hm8A0t23iQ3BZeC
Glmp2ezcTow+VeM02l8Cn4SUuX205VAlJ2d5r2IJvMu+naTMKo8KR3I9D94t
huvMiscaP8vjkwmWr0e73gLXQICxewER97mt1espvQXGS5m41MBdeFJGaEUr
sgjidomxlVgrYMbi1Zng0UKIeexSc05aET3ePOWoMCwE+7jTzTwTipicl91c
mV0AK/ovVlPLlbBCLCewh7sARhmH/CopylijmRI56JMPz/ZriDedU0Gnu53C
/3W+gaw7PoJkFVXM9RgXuHjoDVCsz5uyLqsi3cYyzbkgD/4ZSMugNKkhXrnd
Iy6RB4kKSVlNpur4Q1ifmvQgF4I+Riaalqijx+l4P7mNHDgibv2ifqcGki93
vmoZy4aD7jUnBcM1UKC/7q3paBakbnfc2bisgRTBJNLDtkzYSfsv3vykJm7x
uJqg2fcaYlQqFdvKNdGY09glcfYVuCyxtdYpknBT+nqo30IGOOYtSodHk/C+
YZOiK28GuN62/G1yn4QRarScIM4M8LEs6OaJJaEr/2hWLCEDwpZ9omLiSej1
/qnI+z9UyNZeXUtIJiExWShW5CsVVis2ul6+JiG5KNfgczMVYtp4Iuk1JPTf
c51SE0OFx+luF+7WkdDabY/GdAQV0r2b9Ywb/vZr8VvxhlOhSDTmV0MzCbUP
iRKsg6kwYC98ob2ThLGz5zZPe1KBOCqmNzJKwqhLWycULamgXhAg+ZxBQvXE
/bLWR6mgc6d/1XmChE6OHl1BplQwIybnTk2T8Mi31YwuPSp4XZaWXFggIX+E
/5/w3VQI3Be8+maJhIFOk0zF6lS4wzvS4b1Mwtwb9jfGlamQmJP+78oKCcOb
Dg3ry1Hh2S02cumvv/tki2q9Zajw+rjzocDfJKQvySu8kKBCgWy1xIF1EmZU
xLJ0iVGhfEl+dWODhBqENSt2USr8D1BKgfA=
     "]]}, 
   {Hue[0.3224758424985268, 0.6, 0.6], 
    LineBox[{{4.0816326530612243`*^-7, 1.0000014020612493`}, {
     0.006134358411192534, 1.020279539943357}, {0.012268308659119763`, 
     1.0390301583635122`}, {0.01840225890704699, 1.0563355482929653`}, {
     0.02453620915497422, 1.07227398151311}, {0.03067015940290145, 
     1.0869199008027965`}, {0.03680410965082868, 1.100344101131153}, {
     0.040185543901934066`, 1.1071080174007926`}}], LineBox[CompressedData["
1:eJwVj3c8FI7/gO1s3YlERMZJZZ2SqPc7krIqIRnFZSRKKjJChSQpSkZ9MtLQ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     "]]}, 
   {Hue[0.5585438199983166, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjnc4FYz7h+2MrCMiQjaVcHxJqucpIcrIqleKJBxFUmSX7VghQjKzHStk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     "]]}, 
   {Hue[0.7946117974981064, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlnc4FQ4bho2MbOeUlELI3qc0qPfNDCWZDY7ITAnZeySZIdWxd8pIfkaR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     "]]}, 
   {Hue[0.030679774997896203`, 0.6, 0.6], 
    LineBox[{{4.0816326530612243`*^-7, 1.0000075002945312`}, {
     0.006134358411192534, 1.082737190591541}, {0.011081220051036195`, 
     1.1071080174007926`}}], LineBox[CompressedData["
1:eJwVknc8FP4fx8/e405kFBKJ7DMS9f4gKkklo4HK986RkhEhe51ZZ0tf48zs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     "]]}, 
   {Hue[0.266747752497686, 0.6, 0.6], 
    LineBox[{{4.0816326530612243`*^-7, 1.0000295395278174`}, {
     0.0014616645851324142`, 1.1071080174007926`}}], LineBox[CompressedData["
1:eJwVlWc8FYwfxe1k32uEyiMjpRCXBuX3i2RlFKUkqzISITxW4kEockmyMiPr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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 20}, {0., 1.1071080174007926`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.47321886316962*^9, {3.473219027043924*^9, 3.473219096810546*^9}, {
   3.473219131776911*^9, 3.473219167781952*^9}, 3.473219208107627*^9, {
   3.473219254641157*^9, 3.473219265489365*^9}, {3.473219297494573*^9, 
   3.473219431195844*^9}}]
}, Open  ]]
},
WindowSize->{712, 821},
WindowMargins->{{386, Automatic}, {30, Automatic}},
ShowSelection->True,
FrontEndVersion->"7.0 for Linux x86 (32-bit) (February 25, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[568, 22, 494, 11, 64, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1065, 35, 8527, 232, 561, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[9595, 269, 1463, 35, 143, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[11061, 306, 1267, 32, 143, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[12365, 343, 445, 10, 58, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[12813, 355, 1700, 46, 187, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[14516, 403, 2499, 64, 231, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[17018, 469, 2200, 58, 231, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}]
}, Closed]],
Cell[CellGroupData[{
Cell[19255, 532, 3528, 92, 203, "Input"],
Cell[22786, 626, 166614, 3390, 375, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[189437, 4021, 5136, 147, 297, "Input"],
Cell[194576, 4170, 6365337, 133023, 369, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6559950, 137198, 3007, 84, 275, "Input"],
Cell[6562960, 137284, 2318, 48, 204, "Output"],
Cell[6565281, 137334, 686, 13, 52, "Output"],
Cell[6565970, 137349, 680, 13, 52, "Output"],
Cell[6566653, 137364, 306, 5, 31, "Output"],
Cell[6566962, 137371, 51144, 858, 244, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
